summaryrefslogtreecommitdiff
path: root/src/core/commands.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/core/commands.h')
-rw-r--r--src/core/commands.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/core/commands.h b/src/core/commands.h
index 0dda9f61..c68c5b24 100644
--- a/src/core/commands.h
+++ b/src/core/commands.h
@@ -40,7 +40,8 @@ enum {
CMDERR_NOT_GOOD_IDEA, /* not good idea to do, -yes overrides this */
CMDERR_INVALID_TIME, /* invalid time specification */
CMDERR_INVALID_CHARSET, /* invalid charset specification */
- CMDERR_EVAL_MAX_RECURSE /* eval hit recursion limit */
+ CMDERR_EVAL_MAX_RECURSE, /* eval hit recursion limit */
+ CMDERR_PROGRAM_NOT_FOUND /* program not found */
};
/* Return the full command for `alias' */